package biz.mbisoftware.fn.ejb.entity;

import java.io.Serializable;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.PrePersist;
import javax.persistence.PreUpdate;
import javax.persistence.Table;


import biz.mbisoftware.common.BeanHelper;

import biz.mbisoftware.fn.datatypes.YesNoInt;

/**
 * Arbeitssystem.
 */
@Entity
@Table( name = "mbi_asyst" )
public class MbiAsyst implements Serializable, Comparable<MbiAsyst>
{
    /** Default class version id. */
    private static final long serialVersionUID = 1L;

    /** The length of the char column koart_knz (1). */
    public static final int LEN_KOART_KNZ = 1;

    /** The length of the char column asyst_status_knz (1). */
    public static final int LEN_ASYST_STATUS_KNZ = 1;

    /** Arbeitssystemnummer. */
    @Id
    @Column( name = "asyst_nr", nullable = false )
    private Integer asystNr;

    /** Arbeitssystemkurzbezeichnung. */
    @Column( name = "asyst_kbez", nullable = false )
    private String asystKbez;

    /** Arbeitssystembezeichnung. */
    @Column( name = "asyst_bez", nullable = false )
    private String asystBez;

    /** Arbeitsgangnummer. */
    @Column( name = "arbga_nr", nullable = false )
    private Integer arbgaNr;

    /** Arbeitsplatznummer. */
    @Column( name = "aplaz_nr", nullable = false )
    private Integer aplazNr;

    /** Zeitvariantenzuordnungzuordnungsnummer. */
    @Column( name = "zvz_zuo_nr", nullable = false )
    private Integer zvzZuoNr;

    /** konstante Bearbeitungszeit. */
    @Column( name = "bearb_zt", nullable = false )
    private Float bearbZt;

    /** Bearbeitungszeit Kennzeichen. */
    @Column( name = "bearb_zt_knz", nullable = false )
    private Integer bearbZtKnz;

    /** Anzahl Werker. */
    @Column( name = "werker_anz", nullable = false )
    private Integer werkerAnz;

    /** Kostenarten-Nummer. */
    @Column( name = "koart_nr", nullable = false )
    private Integer koartNr;

    /** Kostenarten-Kennzeichen. */
    @Column( name = "koart_knz", nullable = false, length = MbiAsyst.LEN_KOART_KNZ )
    private String koartKnz;

    /** Arbeitssystemstatuskennzeichen. */
    @Column( name = "asyst_status_knz", nullable = false, length = MbiAsyst.LEN_ASYST_STATUS_KNZ )
    private String asystStatusKnz;

    /** Kostenstellennummer. */
    @Column( name = "k_stelle_nr", nullable = false )
    private Integer kStelleNr;

    /** Kostenstellengruppen-Nummer. */
    @Column( name = "kogrp_nr", nullable = false )
    private Integer kogrpNr;

    /** Variantenfamilien-Nummer. */
    @Column( name = "var_fam_nr", nullable = false )
    private Integer varFamNr;

    /** Variantenkombinations-Id-Nr.. */
    @Column( name = "var_id", nullable = false )
    private Integer varId;

    /** Verweis auf Zeitsystem fr konstante Rstzeit. */
    @Column( name = "ruest_apbzt_nr_con", nullable = false )
    private Integer ruestApbztNrCon;

    /** konstante Rstzeit. */
    @Column( name = "ruest_zt_const", nullable = false )
    private Float ruestZtConst;

    /** Verweis auf Zeitsystem fr normierte Rstzeit. */
    @Column( name = "ruest_apbzt_nr_nor", nullable = false )
    private Integer ruestApbztNrNor;

    /** normierte Rstzeit. */
    @Column( name = "ruest_zt_norm", nullable = false )
    private Float ruestZtNorm;

    /** Verweis auf ein Zeitsystem fr die Bearbeitungsz.. */
    @Column( name = "bearb_apbzt_nr", nullable = false )
    private Integer bearbApbztNr;

    /** Belegdruck-Spezifika. */
    @Column( name = "bel_spez", nullable = false )
    private Integer belSpez;

    /** Textnummer. */
    @Column( name = "text_nr", nullable = false )
    private Integer textNr;

    /** Kalkulationsfehlerprotokoll-Kennzeichen. */
    @Column( name = "kalk_protokoll_knz", nullable = false )
    private Integer kalkProtokollKnz;

    /** BDV-Meldekennzeichen. */
    @Column( name = "melde_knz", nullable = false )
    private Integer meldeKnz;

    /**
     * Initialize all non-nullable fields.
     */
    @PrePersist
    @PreUpdate
    public void avoidNulls()
    {
        if ( this.asystNr == null ) this.asystNr = Integer.valueOf( 0 );
        if ( this.asystKbez == null ) this.asystKbez = " ";
        if ( this.asystBez == null ) this.asystBez = " ";
        if ( this.arbgaNr == null ) this.arbgaNr = Integer.valueOf( 0 );
        if ( this.aplazNr == null ) this.aplazNr = Integer.valueOf( 0 );
        if ( this.zvzZuoNr == null ) this.zvzZuoNr = Integer.valueOf( 0 );
        if ( this.bearbZt == null ) this.bearbZt = Float.valueOf( 0 );
        if ( this.bearbZtKnz == null ) this.bearbZtKnz = Integer.valueOf( 0 );
        if ( this.werkerAnz == null ) this.werkerAnz = Integer.valueOf( 0 );
        if ( this.koartNr == null ) this.koartNr = Integer.valueOf( 0 );
        if ( this.koartKnz == null ) this.koartKnz = " ";
        if ( this.asystStatusKnz == null ) this.asystStatusKnz = " ";
        if ( this.kStelleNr == null ) this.kStelleNr = Integer.valueOf( 0 );
        if ( this.kogrpNr == null ) this.kogrpNr = Integer.valueOf( 0 );
        if ( this.varFamNr == null ) this.varFamNr = Integer.valueOf( 0 );
        if ( this.varId == null ) this.varId = Integer.valueOf( 0 );
        if ( this.ruestApbztNrCon == null ) this.ruestApbztNrCon = Integer.valueOf( 0 );
        if ( this.ruestZtConst == null ) this.ruestZtConst = Float.valueOf( 0 );
        if ( this.ruestApbztNrNor == null ) this.ruestApbztNrNor = Integer.valueOf( 0 );
        if ( this.ruestZtNorm == null ) this.ruestZtNorm = Float.valueOf( 0 );
        if ( this.bearbApbztNr == null ) this.bearbApbztNr = Integer.valueOf( 0 );
        if ( this.belSpez == null ) this.belSpez = Integer.valueOf( 0 );
        if ( this.textNr == null ) this.textNr = Integer.valueOf( 0 );
        if ( this.kalkProtokollKnz == null ) this.kalkProtokollKnz = Integer.valueOf( 0 );
    }

    /**
     * @return Returns the asystNr (Arbeitssystemnummer).
     */
    public Integer getAsystNr()
    {
        return this.asystNr;
    }

    /**
     * @param asystNr  The asystNr to set (Arbeitssystemnummer).
     */
    public void setAsystNr( final Integer asystNr )
    {
        this.asystNr = asystNr;
    }

    /**
     * @return Returns the asystKbez (Arbeitssystemkurzbezeichnung).
     */
    public String getAsystKbez()
    {
        return this.asystKbez;
    }

    /**
     * @param asystKbez  The asystKbez to set (Arbeitssystemkurzbezeichnung).
     */
    public void setAsystKbez( final String asystKbez )
    {
        this.asystKbez = asystKbez;
    }

    /**
     * @return Returns the asystBez (Arbeitssystembezeichnung).
     */
    public String getAsystBez()
    {
        return this.asystBez;
    }

    /**
     * @param asystBez  The asystBez to set (Arbeitssystembezeichnung).
     */
    public void setAsystBez( final String asystBez )
    {
        this.asystBez = asystBez;
    }

    /**
     * @return Returns the arbgaNr (Arbeitsgangnummer).
     */
    public Integer getArbgaNr()
    {
        return this.arbgaNr;
    }

    /**
     * @param arbgaNr  The arbgaNr to set (Arbeitsgangnummer).
     */
    public void setArbgaNr( final Integer arbgaNr )
    {
        this.arbgaNr = arbgaNr;
    }

    /**
     * @return Returns the aplazNr (Arbeitsplatznummer).
     */
    public Integer getAplazNr()
    {
        return this.aplazNr;
    }

    /**
     * @param aplazNr  The aplazNr to set (Arbeitsplatznummer).
     */
    public void setAplazNr( final Integer aplazNr )
    {
        this.aplazNr = aplazNr;
    }

    /**
     * @return Returns the zvzZuoNr (Zeitvariantenzuordnungzuordnungsnummer).
     */
    public Integer getZvzZuoNr()
    {
        return this.zvzZuoNr;
    }

    /**
     * @param zvzZuoNr  The zvzZuoNr to set (Zeitvariantenzuordnungzuordnungsnummer).
     */
    public void setZvzZuoNr( final Integer zvzZuoNr )
    {
        this.zvzZuoNr = zvzZuoNr;
    }

    /**
     * @return Returns the bearbZt (konstante Bearbeitungszeit).
     */
    public Float getBearbZt()
    {
        return this.bearbZt;
    }

    /**
     * @param bearbZt  The bearbZt to set (konstante Bearbeitungszeit).
     */
    public void setBearbZt( final Float bearbZt )
    {
        this.bearbZt = bearbZt;
    }

    /**
     * @return Returns the bearbZtKnz (Bearbeitungszeit Kennzeichen).
     */
    public Integer getBearbZtKnz()
    {
        return this.bearbZtKnz;
    }

    /**
     * @param bearbZtKnz  The bearbZtKnz to set (Bearbeitungszeit Kennzeichen).
     */
    public void setBearbZtKnz( final Integer bearbZtKnz )
    {
        this.bearbZtKnz = bearbZtKnz;
    }

    /**
     * @return Returns the werkerAnz (Anzahl Werker).
     */
    public Integer getWerkerAnz()
    {
        return this.werkerAnz;
    }

    /**
     * @param werkerAnz  The werkerAnz to set (Anzahl Werker).
     */
    public void setWerkerAnz( final Integer werkerAnz )
    {
        this.werkerAnz = werkerAnz;
    }

    /**
     * @return Returns the koartNr (Kostenarten-Nummer).
     */
    public Integer getKoartNr()
    {
        return this.koartNr;
    }

    /**
     * @param koartNr  The koartNr to set (Kostenarten-Nummer).
     */
    public void setKoartNr( final Integer koartNr )
    {
        this.koartNr = koartNr;
    }

    /**
     * @return Returns the koartKnz (Kostenarten-Kennzeichen).
     */
    public String getKoartKnz()
    {
        return this.koartKnz;
    }

    /**
     * @param koartKnz  The koartKnz to set (Kostenarten-Kennzeichen).
     */
    public void setKoartKnz( final String koartKnz )
    {
        this.koartKnz = koartKnz;
    }

    /**
     * @return Returns the asystStatusKnz (Arbeitssystemstatuskennzeichen).
     */
    public String getAsystStatusKnz()
    {
        return this.asystStatusKnz;
    }

    /**
     * @param asystStatusKnz  The asystStatusKnz to set (Arbeitssystemstatuskennzeichen).
     */
    public void setAsystStatusKnz( final String asystStatusKnz )
    {
        this.asystStatusKnz = asystStatusKnz;
    }

    /**
     * @return Returns the kStelleNr (Kostenstellennummer).
     */
    public Integer getKStelleNr()
    {
        return this.kStelleNr;
    }

    /**
     * @param kStelleNr  The kStelleNr to set (Kostenstellennummer).
     */
    public void setKStelleNr( final Integer kStelleNr )
    {
        this.kStelleNr = kStelleNr;
    }

    /**
     * @return Returns the kogrpNr (Kostenstellengruppen-Nummer).
     */
    public Integer getKogrpNr()
    {
        return this.kogrpNr;
    }

    /**
     * @param kogrpNr  The kogrpNr to set (Kostenstellengruppen-Nummer).
     */
    public void setKogrpNr( final Integer kogrpNr )
    {
        this.kogrpNr = kogrpNr;
    }

    /**
     * @return Returns the varFamNr (Variantenfamilien-Nummer).
     */
    public Integer getVarFamNr()
    {
        return this.varFamNr;
    }

    /**
     * @param varFamNr  The varFamNr to set (Variantenfamilien-Nummer).
     */
    public void setVarFamNr( final Integer varFamNr )
    {
        this.varFamNr = varFamNr;
    }

    /**
     * @return Returns the varId (Variantenkombinations-Id-Nr.).
     */
    public Integer getVarId()
    {
        return this.varId;
    }

    /**
     * @param varId  The varId to set (Variantenkombinations-Id-Nr.).
     */
    public void setVarId( final Integer varId )
    {
        this.varId = varId;
    }

    /**
     * @return Returns the ruestApbztNrCon (Verweis auf Zeitsystem fr konstante Rstzeit).
     */
    public Integer getRuestApbztNrCon()
    {
        return this.ruestApbztNrCon;
    }

    /**
     * @param ruestApbztNrCon  The ruestApbztNrCon to set (Verweis auf Zeitsystem fr konstante Rstzeit).
     */
    public void setRuestApbztNrCon( final Integer ruestApbztNrCon )
    {
        this.ruestApbztNrCon = ruestApbztNrCon;
    }

    /**
     * @return Returns the ruestZtConst (konstante Rstzeit).
     */
    public Float getRuestZtConst()
    {
        return this.ruestZtConst;
    }

    /**
     * @param ruestZtConst  The ruestZtConst to set (konstante Rstzeit).
     */
    public void setRuestZtConst( final Float ruestZtConst )
    {
        this.ruestZtConst = ruestZtConst;
    }

    /**
     * @return Returns the ruestApbztNrNor (Verweis auf Zeitsystem fr normierte Rstzeit).
     */
    public Integer getRuestApbztNrNor()
    {
        return this.ruestApbztNrNor;
    }

    /**
     * @param ruestApbztNrNor  The ruestApbztNrNor to set (Verweis auf Zeitsystem fr normierte Rstzeit).
     */
    public void setRuestApbztNrNor( final Integer ruestApbztNrNor )
    {
        this.ruestApbztNrNor = ruestApbztNrNor;
    }

    /**
     * @return Returns the ruestZtNorm (normierte Rstzeit).
     */
    public Float getRuestZtNorm()
    {
        return this.ruestZtNorm;
    }

    /**
     * @param ruestZtNorm  The ruestZtNorm to set (normierte Rstzeit).
     */
    public void setRuestZtNorm( final Float ruestZtNorm )
    {
        this.ruestZtNorm = ruestZtNorm;
    }

    /**
     * @return Returns the bearbApbztNr (Verweis auf ein Zeitsystem fr die Bearbeitungsz.).
     */
    public Integer getBearbApbztNr()
    {
        return this.bearbApbztNr;
    }

    /**
     * @param bearbApbztNr  The bearbApbztNr to set (Verweis auf ein Zeitsystem fr die Bearbeitungsz.).
     */
    public void setBearbApbztNr( final Integer bearbApbztNr )
    {
        this.bearbApbztNr = bearbApbztNr;
    }

    /**
     * @return Returns the belSpez (Belegdruck-Spezifika).
     */
    public Integer getBelSpez()
    {
        return this.belSpez;
    }

    /**
     * @param belSpez  The belSpez to set (Belegdruck-Spezifika).
     */
    public void setBelSpez( final Integer belSpez )
    {
        this.belSpez = belSpez;
    }

    /**
     * @return Returns the textNr (Textnummer).
     */
    public Integer getTextNr()
    {
        return this.textNr;
    }

    /**
     * @param textNr  The textNr to set (Textnummer).
     */
    public void setTextNr( final Integer textNr )
    {
        this.textNr = textNr;
    }

    /**
     * @return Returns the kalkProtokollKnz (Kalkulationsfehlerprotokoll-Kennzeichen).
     */
    public Integer getKalkProtokollKnz()
    {
        return this.kalkProtokollKnz;
    }

    /**
     * @param kalkProtokollKnz  The kalkProtokollKnz to set (Kalkulationsfehlerprotokoll-Kennzeichen).
     */
    public void setKalkProtokollKnz( final Integer kalkProtokollKnz )
    {
        this.kalkProtokollKnz = kalkProtokollKnz;
    }

    /**
     * @return Returns the meldeKnz (BDV-Meldekennzeichen).
     */
    public YesNoInt getMeldeKnz()
    {
        return YesNoInt.parse( this.meldeKnz );
    }

    /**
     * @param meldeKnz  The meldeKnz to set (BDV-Meldekennzeichen).
     */
    public void setMeldeKnz( final YesNoInt meldeKnz )
    {
        this.meldeKnz = meldeKnz.getValue();
    }

    @Override
    public final boolean equals( final Object obj )
    {
        return BeanHelper.equals( this, obj, "AsystNr" );
    }

    @Override
    public final int hashCode()
    {
        return BeanHelper.hashCode( this, "AsystNr" );
    }

    @Override
    public final String toString()
    {
        return BeanHelper.toString( this, "AsystNr" );
    }

    @Override
    public final int compareTo( final MbiAsyst obj )
    {
        return BeanHelper.compareTo( this, obj, "AsystNr" );
    }
}
